@@ -2,20 +2,24 @@
 
 #include "aria2.h"
 #include "xmlrpc.h"
+#include <iostream>
 #include <sstream>
 #include <thread>
 #include <chrono>
 #include <tools/otherTools.h>
 #include <tools/pathTools.h>
+#include <tools/stringTools.h>
 #include <downloader.h> // For AriaError
 
 #ifdef _WIN32
 # define ARIA2_CMD "aria2c.exe"
 #else
 # define ARIA2_CMD "aria2c"
+# include <unistd.h>
 #endif
 
 
+
 namespace kiwix {
 
 Aria2::Aria2():
