@@ -17,7 +17,7 @@
  * MA 02110-1301, USA.
  */
 
-#include <tools/pathTools.h>
+#include "tools/pathTools.h"
 
 #ifdef __APPLE__
 #include <limits.h>
@@ -29,6 +29,17 @@
 #define getcwd _getcwd  // stupid MSFT "deprecation" warning
 #endif
 
+#include "tools/stringTools.h"
+
+#include <string.h>
+#include <map>
+#include <vector>
+#include <sys/stat.h>
+#include <sstream>
+#include <fstream>
+#include <iomanip>
+#include <iostream>
+
 #ifdef _WIN32
 const std::string SEPARATOR("\\");
 #else
@@ -42,7 +53,7 @@ const std::string SEPARATOR("/");
 #define PATH_MAX 1024
 #endif
 
-bool isRelativePath(const string& path)
+bool isRelativePath(const std::string& path)
 {
 #ifdef _WIN32
   return path.empty() || path.substr(1, 2) == ":\\" ? false : true;
@@ -51,7 +62,7 @@ bool isRelativePath(const string& path)
 #endif
 }
 
-string computeRelativePath(const string path, const string absolutePath)
+std::string computeRelativePath(const std::string& path, const std::string& absolutePath)
 {
   std::vector<std::string> pathParts = kiwix::split(path, SEPARATOR);
   std::vector<std::string> absolutePathParts
@@ -64,7 +75,7 @@ string computeRelativePath(const string path, const string absolutePath)
       commonCount++;
   }
 
-  string relativePath;
+  std::string relativePath;
 #ifdef _WIN32
   /* On Windows you have a token more because the root is represented
      by a letter */
@@ -83,10 +94,16 @@ string computeRelativePath(const string path, const string absolutePath)
   return relativePath;
 }
 
+#ifdef _WIN32
+# define STRTOK strtok_s
+#else
+# define STRTOK strtok_r
+#endif
+
 /* Warning: the relative path must be with slashes */
-string computeAbsolutePath(const string path, const string relativePath)
+std::string computeAbsolutePath(const std::string& path, const std::string& relativePath)
 {
-  string absolutePath;
+  std::string absolutePath;
 
   if (path.empty()) {
     char* path = NULL;
@@ -98,7 +115,7 @@ string computeAbsolutePath(const string path, const string relativePath)
     path = getcwd(path, size);
 #endif
 
-    absolutePath = string(path) + SEPARATOR;
+    absolutePath = std::string(path) + SEPARATOR;
   } else {
     absolutePath = path.substr(path.length() - 1, 1) == SEPARATOR
                        ? path
@@ -110,31 +127,33 @@ string computeAbsolutePath(const string path, const string relativePath)
 #else
   char* cRelativePath = strdup(relativePath.c_str());
 #endif
-  char* token = strtok(cRelativePath, "/");
+  char* saveptr = nullptr;
+  char* token = STRTOK(cRelativePath, "/", &saveptr);
 
   while (token != NULL) {
-    if (string(token) == "..") {
+    if (std::string(token) == "..") {
       absolutePath = removeLastPathElement(absolutePath, true, false);
-      token = strtok(NULL, "/");
+      token = STRTOK(NULL, "/", &saveptr);
     } else if (strcmp(token, ".") && strcmp(token, "")) {
-      absolutePath += string(token);
-      token = strtok(NULL, "/");
+      absolutePath += std::string(token);
+      token = STRTOK(NULL, "/", &saveptr);
       if (token != NULL) {
         absolutePath += SEPARATOR;
       }
     } else {
-      token = strtok(NULL, "/");
+      token = STRTOK(NULL, "/", &saveptr);
     }
   }
+  free(cRelativePath);
 
   return absolutePath;
 }
 
-string removeLastPathElement(const string path,
-                             const bool removePreSeparator,
-                             const bool removePostSeparator)
+std::string removeLastPathElement(const std::string& path,
+                                  const bool removePreSeparator,
+                                  const bool removePostSeparator)
 {
-  string newPath = path;
+  std::string newPath = path;
   size_t offset = newPath.find_last_of(SEPARATOR);
   if (removePreSeparator &&
 #ifndef _WIN32
@@ -149,18 +168,18 @@ string removeLastPathElement(const string path,
   return newPath;
 }
 
-string appendToDirectory(const string& directoryPath, const string& filename)
+std::string appendToDirectory(const std::string& directoryPath, const std::string& filename)
 {
-  string newPath = directoryPath + SEPARATOR + filename;
+  std::string newPath = directoryPath + SEPARATOR + filename;
   return newPath;
 }
 
-string getLastPathElement(const string& path)
+std::string getLastPathElement(const std::string& path)
 {
   return path.substr(path.find_last_of(SEPARATOR) + 1);
 }
 
-unsigned int getFileSize(const string& path)
+unsigned int getFileSize(const std::string& path)
 {
 #ifdef _WIN32
   struct _stat filestatus;
@@ -173,14 +192,14 @@ unsigned int getFileSize(const string& path)
   return filestatus.st_size / 1024;
 }
 
-string getFileSizeAsString(const string& path)
+std::string getFileSizeAsString(const std::string& path)
 {
-  ostringstream convert;
+  std::ostringstream convert;
   convert << getFileSize(path);
   return convert.str();
 }
 
-string getFileContent(const string& path)
+std::string getFileContent(const std::string& path)
 {
   std::ifstream f(path, std::ios::in|std::ios::ate);
   std::string content;
@@ -194,14 +213,14 @@ string getFileContent(const string& path)
   return content;
 }
 
-bool fileExists(const string& path)
+bool fileExists(const std::string& path)
 {
 #ifdef _WIN32
   return PathFileExists(path.c_str());
 #else
   bool flag = false;
-  fstream fin;
-  fin.open(path.c_str(), ios::in);
+  std::fstream fin;
+  fin.open(path.c_str(), std::ios::in);
   if (fin.is_open()) {
     flag = true;
   }
@@ -210,7 +229,7 @@ bool fileExists(const string& path)
 #endif
 }
 
-bool makeDirectory(const string& path)
+bool makeDirectory(const std::string& path)
 {
 #ifdef _WIN32
   int status = _mkdir(path.c_str());
@@ -220,7 +239,7 @@ bool makeDirectory(const string& path)
   return status == 0;
 }
 
-string makeTmpDirectory()
+std::string makeTmpDirectory()
 {
 #ifdef _WIN32
   char cbase[MAX_PATH];
@@ -231,16 +250,16 @@ string makeTmpDirectory()
   GetTempFileName(cbase, "kiwix", 0, ctmp);
   DeleteFile(ctmp);
   _mkdir(ctmp);
-  return string(ctmp);
+  return std::string(ctmp);
 #else
   char _template_array[] = {"/tmp/kiwix-lib_XXXXXX"};
-  string dir = mkdtemp(_template_array);
+  std::string dir = mkdtemp(_template_array);
   return dir;
 #endif
 }
 
 /* Try to create a link and if does not work then make a copy */
-bool copyFile(const string& sourcePath, const string& destPath)
+bool copyFile(const std::string& sourcePath, const std::string& destPath)
 {
   try {
 #ifndef _WIN32
@@ -252,15 +271,15 @@ bool copyFile(const string& sourcePath, const string& destPath)
 #ifndef _WIN32
     }
 #endif
-  } catch (exception& e) {
-    cerr << e.what() << endl;
+  } catch (std::exception& e) {
+    std::cerr << e.what() << std::endl;
     return false;
   }
 
   return true;
 }
 
-string getExecutablePath()
+std::string getExecutablePath()
 {
   char binRootPath[PATH_MAX];
 
@@ -281,7 +300,7 @@ string getExecutablePath()
   return "";
 }
 
-bool writeTextFile(const string& path, const string& content)
+bool writeTextFile(const std::string& path, const std::string& content)
 {
   std::ofstream file;
   file.open(path.c_str());
@@ -290,15 +309,15 @@ bool writeTextFile(const string& path, const string& content)
   return true;
 }
 
-string getCurrentDirectory()
+std::string getCurrentDirectory()
 {
   char* a_cwd = getcwd(NULL, 0);
-  string s_cwd(a_cwd);
+  std::string s_cwd(a_cwd);
   free(a_cwd);
   return s_cwd;
 }
 
-string getDataDirectory()
+std::string getDataDirectory()
 {
 #ifdef _WIN32
   char* cDataDir = ::getenv("APPDATA");
@@ -323,3 +342,49 @@ string getDataDirectory()
 #endif
   return appendToDirectory(dataDir, "kiwix");
 }
+
+static std::map<std::string, std::string> extMimeTypes = {
+ { "html", "text/html"},
+ { "htm", "text/html"},
+ { "png", "image/png"},
+ { "tiff", "image/tiff"},
+ { "tif", "image/tiff"},
+ { "jpeg", "image/jpeg"},
+ { "jpg", "image/jpeg"},
+ { "gif", "image/gif"},
+ { "svg", "image/svg+xml"},
+ { "txt", "text/plain"},
+ { "xml", "text/xml"},
+ { "pdf", "application/pdf"},
+ { "ogg", "application/ogg"},
+ { "js", "application/javascript"},
+ { "css", "text/css"},
+ { "otf", "application/vnd.ms-opentype"},
+ { "ttf", "application/font-ttf"},
+ { "woff", "application/font-woff"},
+ { "vtt", "text/vtt"}
+};
+
+/* Try to get the mimeType from the file extension */
+std::string getMimeTypeForFile(const std::string& filename)
+{
+  std::string mimeType = "text/plain";
+  auto pos = filename.find_last_of(".");
+
+  if (pos != std::string::npos) {
+    std::string extension = filename.substr(pos + 1);
+
+    auto it = extMimeTypes.find(extension);
+    if (it != extMimeTypes.end()) {
+      mimeType = it->second;
+    } else {
+      it = extMimeTypes.find(kiwix::lcAll(extension));
+      if (it != extMimeTypes.end()) {
+        mimeType = it->second;
+      }
+    }
+  }
+
+  return mimeType;
+}
+
