@@ -5,13 +5,15 @@ set -e
 BUILD_DIR=${HOME}/BUILD_${PLATFORM}
 INSTALL_DIR=${BUILD_DIR}/INSTALL
 
-
+TEST=0
 case ${PLATFORM} in
     "native_static")
          MESON_OPTION="--default-library=static"
+         TEST=1
          ;;
     "native_dyn")
          MESON_OPTION="--default-library=shared"
+         TEST=1
          ;;
     "win32_static")
          MESON_OPTION="--default-library=static --cross-file ${BUILD_DIR}/meson_cross_file.txt"
@@ -39,3 +41,9 @@ export CPPFLAGS="-I${INSTALL_DIR}/include"
 meson . build ${MESON_OPTION}
 cd build
 ninja
+if [[ "$TEST" == "1" ]]
+then
+  echo "Running test"
+  export LD_LIBRARY_PATH=${INSTALL_DIR}/lib:${INSTALL_DIR}/lib64:${INSTALL_DIR}/lib/x86_64-linux-gnu
+  ninja test
+fi
